@@ -7,7 +7,7 @@ add.dist.error <- function(no.files, path, cv = NULL, distribution, beta.params
       error <- rnorm(nrow(ddf.data), mean = 0, sd = cv*ddf.data$distance)
       new.distances <- ddf.data$distance + error
       if(range(new.distances)[1] < 0){
-        message("Warning distances less than 0 have been generatesd. The absolute value of these negative values will be used and the errors are no longer be normally distributed.")
+        warning("Distances less than 0 have been generatesd. The absolute value of these negative values will be used therefore the errors are no longer Normally-distributed.", call. = FALSE, immediate. = TRUE)
       }
       new.distances <- abs(new.distances)
     #Add Log-Normal errors
