@@ -39,7 +39,7 @@ check.intersection <- function(transect, point, display.diagnostics = FALSE){
   #c = y - mx
   transect.c <- transect[["start.Y"]] - transect.m*transect[["start.X"]]
   if(abs((transect.m*new.x.coord + transect.c)-new.y.coord) > 1.0e-3 &  abs((transect.m*new.x.coord + transect.c)-new.y.coord) < delta.Y/2){
-    message("Warning: error tolerance not big enough to check intersection")
+    warning("error tolerance not big enough to check intersection")
   }
   #Thorougly tested this function now so removing this warning (see inst folder for tests)
 #   if(delta.Y/2 < 1.0e-3){
@@ -52,7 +52,7 @@ check.intersection <- function(transect, point, display.diagnostics = FALSE){
   if(display.diagnostics){      
     lines(c(point[["x"]], new.x.coord), c(point[["y"]], new.y.coord), col = 3, lty = 1) 
     new.m <- (new.y.coord-point[["y"]])/(new.x.coord-point[["x"]])
-    message("Gradient.check: m between points = ", round(new.m, 3), ", perpendicular m = ",round(perpendicular.m,3))   
+    #warning("Gradient.check: m between points = ", round(new.m, 3), ", perpendicular m = ",round(perpendicular.m,3))   
   }
   #check to see if it  within the x-range of the transect
   if(transect[["start.X"]] < transect[["end.X"]]){
